/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@ricochet.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001-2004 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.ui.jsp;

import java.io.IOException;
import javax.servlet.jsp.*;
import javax.servlet.jsp.tagext.*;
import com.silverwrist.venice.ui.*;
import com.silverwrist.venice.ui.helpers.HTMLRendering;

public class UtilButtonTag extends VeniceTagSupport
{
  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private String m_type = "img";
  private String m_id = null;

  /*--------------------------------------------------------------------------------
   * Overrides from class TagSupport
   *--------------------------------------------------------------------------------
   */

  public int doStartTag() throws JspException
  {
    if (m_id==null)
      throw new JspTagException("<util:button/> ID not specified!");
    if (!(m_type.equals("img") || m_type.equals("input")))
      throw new JspTagException("<util:button/> type not valid!");

    String data;
    HTMLRendering html = (HTMLRendering)(getRequestOutput().queryService(HTMLRendering.class));
    if (m_type.equals("img"))
      data = html.getButtonVisual(m_id);
    else
      data = html.getButtonInput(m_id);

    try
    { // write out what we came here to accomplish
      JspWriter out = pageContext.getOut();
      out.write(data);

    } // end try
    catch (IOException e)
    { // convert the I/O error into something the servlet engine can deal with
      throw new JspTagException("error writing button - " + e.getMessage());

    } // end catch

    return SKIP_BODY;

  } // end doStartTag

  public void release()
  {
    super.release();
    m_type = "img";
    m_id = null;

  } // end release
  
  /*--------------------------------------------------------------------------------
   * Attribute set functions
   *--------------------------------------------------------------------------------
   */

  public void setType(String s)
  {
    m_type = s.trim().toLowerCase();

  } // end setType

  public void setId(String s)
  {
    m_id = s;

  } // end setId

} // end class UtilButtonTag
